// errors mixin
// accepts vuelidate object
// returns an array of string error messages
// supports vue-i18n

export default {
  methods: {
    getErrors (v, key) {
      let arr = []
      if (typeof v === 'object') { // are there any validation rules
        if (v.$error) { // is any validator invalid
          for (const [validator, params] of Object.entries(v.$params)) {
            console.log('for key ' + key + ' and validator ' + validator + ' value is ' + v[validator])
            if (!v[validator] && !v.$pending) { // is validator set to invalid and not a promise
              if (this.$i18n) { // is vue-i18n available
                arr.push(this.$i18n.t('formics.validation.' + validator, params))
              } else {
                arr.push(this.messages[validator])
              }
            }
          }
          return arr
        }
      }
      return []
    },
    getText (category, text, params) {
      // we declare labels, placeholders and errors separately because this way they're more flexible and reusable across multiple forms
      return this.$i18n ? this.$i18n.t('formics.' + category + '.' + text, params) : text
    },
    getSlot (slot, key, from) {
      let slots = this.slots || ['label', 'hint', 'field', 'error']
      console.log('from: ' + from + ' is: ' + key + (slots.indexOf(slot) + 1))
      return key + (slots.indexOf(slot) + 1)
    },
    isActive (field) {
      return !field.hasOwnProperty('active') ? true : (typeof field.active === 'function' ? field.active() : field.active)
    },
    areEqual (left, right) {
      return JSON.stringify(left) === JSON.stringify(right)
    }
  }
}
